@@ -4,16 +4,19 @@ import time
 
 class Retries(Function):
     def _init(self, times, delay=0):
+        if times <= 0:
+            raise Exception('Times should be positive.')
         self._times = times
         self._delay = delay
         
     def _call(self, *args, **kw):
-        for _ in range(self._times):
+        for i in range(self._times):
             try:
                 return super(Retries, self)._call(*args, **kw)
             except Exception as e:
                 last_error = e
-                time.sleep(self._delay)
+                if i != self._times:
+                    time.sleep(self._delay)
         else:
             raise last_error
         
\ No newline at end of file
