@@ -11,9 +11,9 @@ def load_modules(packages):
     for package in packages:
         if not inspect.ismodule(package):
             package = importlib.import_module(package)
-        for loader, mod, _ in pkgutil.walk_packages(path=package.__path__, prefix=package.__name__ + '.'):
+        for _, mod, _ in pkgutil.walk_packages(path=package.__path__, prefix=package.__name__ + '.'):
             if mod not in sys.modules:
-                loader.find_module(mod).load_module(mod)
+                importlib.import_module(mod)
                 
 def module_exists(modname):
     '''
@@ -25,7 +25,7 @@ def module_exists(modname):
     try:
         importlib.import_module(modname)
         return True
-    except:
+    except ImportError:
         return False
     
 if __name__ == '__main__':
